@@ -32,7 +32,7 @@ class Dispatch(object):
 	
 	"""
 
-	def __init__(self, server, username=None, password=None, debug=False):
+	def __init__(self, server, username=None, password=None, tls=None, debug=False):
 		"""Initialize the Dispatch class.
 		
 		Authentication is only performed if both I{username} and
@@ -60,6 +60,7 @@ class Dispatch(object):
 		self.server = server
 		self.username = username
 		self.password = password
+		self.tls = tls
 		self.debug = debug
 		self.log = None
 		
@@ -86,14 +87,16 @@ class Dispatch(object):
 		log.info("Connecting to SMTP server %s." % self.server)
 		self.connection.connect(self.server)
 
-		try:
+		if self.tls or self.tls is None:
 			self.connection.ehlo()
-			self.connection.starttls()
-			self.connection.ehlo()
-			log.debug("TLS enabled on SMTP server.")
-
-		except:
-			log.warn("TLS not available on SMTP server.")
+			
+			if self.connection.has_extn('STARTTLS') or self.tls:
+				self.connection.starttls()
+				self.connection.ehlo()
+				log.debug("TLS enabled on SMTP server.")
+			
+			else:
+				log.warn("TLS not available on SMTP server.")
 
 		if self.username and self.password:
 			log.debug("Authenticating as %s." % self.username)
@@ -125,7 +128,7 @@ class Dispatch(object):
 		
 		pack = message()
 		
-		log.info("\"%s\" >> \"%s\" :: \"%s\"" % (pack[0], pack[1], message.message['Subject']))
+		log.info("\"%s\" >> \"%s\" :: \"%s\"" % (pack[0], pack[1], message._message['Subject']))
 		self.connection.sendmail(*pack)
 		
 		if self.debug: self.disconnect()
