@@ -2,7 +2,7 @@
 
 """MIME-encoded electronic mail message classes."""
 
-import turbogears
+import turbogears, re
 
 from email.Utils import formatdate
 from email.MIMEMultipart import MIMEMultipart
@@ -13,6 +13,8 @@ from email.Encoders import encode_base64
 
 __all__ = ['Message', 'TemplateMessage']
 
+_rich_to_plain = re.compile(r"(<[^>]+>)")
+
 
 class Message(object):
 	"""Simple e-mail message class.
@@ -42,7 +44,7 @@ class Message(object):
 	"""
 	
 	
-	def __init__(self, sender, recipient, subject):
+	def __init__(self, sender, recipient, subject, encoding=None):
 		"""Instantiate a new Message object.
 		
 		An instance of Message is callable.
@@ -58,6 +60,12 @@ class Message(object):
 		@param subject: The subject of the message.	 This gets encoded
 						as the "Subject:" SMTP header.
 		@type subject: string
+		
+		@param encoding: The encoding to send the text parts of the
+		                 message contents as.  Note that this does not
+		                 perform any conversion for you, it simply
+		                 passes this value to MIMEText().
+		@type encoding: string
 		"""
 		
 		super(Message, self).__init__()
@@ -65,6 +73,7 @@ class Message(object):
 		self._message = MIMEMultipart() # ('related')
 		self._processed = False
 		self._attachments = []
+		self._charset = [turbogears.config.get("mail.encoding", 'us-ascii'), encoding][encoding is None]
 		
 		self.plain = None
 		self.rich = None
@@ -122,17 +131,25 @@ class Message(object):
 		self._attachments.append(part)
 
 	def _process(self):
-		"""Produce the final MIME message."""
+		"""Produce the final MIME message.
+		
+		Additinoally, if only a rich text part exits, strip the HTML to
+		produce the plain text part.  (This produces identical output as
+		KID.)
+		"""
+		
+		if self.rich and not self.plain:
+			self.plain = _rich_to_plain.sub('', self.rich)
 		
 		if self.plain and self.rich:
 			alternative = MIMEMultipart('alternative')
 			self._message.attach(alternative)
 			
-			alternative.attach(MIMEText(self.plain))
-			alternative.attach(MIMEText(self.rich, 'html'))
+			alternative.attach(MIMEText(self.plain, _charset=self._charset))
+			alternative.attach(MIMEText(self.rich, 'html', _charset=self._charset))
 		
 		else:
-			self._message.attach(MIMEText(self.plain))
+			self._message.attach(MIMEText(self.plain, _charset=self._charset))
 		
 		for attachment in self._attachments:
 			self._message.attach(attachment)
@@ -164,12 +181,16 @@ class TemplateMessage(Message):
 				"from@host.com",
 				"to@host.com",
 				"Subject",
-				"app.templates.mail"
+				"app.templates.mail",
+				dict()
 			)
-		message.plain = "This is a plain message."
+	
+	Do not specify message.plain or message.rich content - the template
+	will override what you set.  If you wish to hand-produce content,
+	use the Message class.
 	"""
 	
-	def __init__(self, sender, recipient, subject, template, variables={}):
+	def __init__(self, sender, recipient, subject, template, variables={}, encoding=None):
 		"""Store the additonal template and variable information.
 		
 		@param template: A dot-path to a valid KID template.
@@ -184,9 +205,9 @@ class TemplateMessage(Message):
 		self._variables = dict(sender=sender, recipient=recipient, subject=subject)
 		self._variables.update(variables)
 				
-		super(TemplateMessage, self).__init__(sender, recipient, subject)
+		super(TemplateMessage, self).__init__(sender, recipient, subject, encoding)
 	
-	def process(self):
+	def _process(self):
 		"""Automatically generate the plain and rich text content."""
 		
 		turbogears.view.base._load_engines()
@@ -205,4 +226,4 @@ class TemplateMessage(Message):
 		self.plain = render.serialize(output="plain")			
 		self.rich = render.serialize(output="html")
 		
-		return super(TemplateMessage, self).process()
+		return super(TemplateMessage, self)._process()
