@@ -73,6 +73,11 @@ class Pool(Thread):
 		log.debug("Shutdown requested.")
 		self._finished.set()
 
+	def spawn(self):
+		thread = Thread(target=self.wrapper)
+		thread.start()
+		self._pool += 1
+
 	def run(self):
 		"""The management thread.
 		
@@ -94,9 +99,7 @@ class Pool(Thread):
 			if not self._queue.empty() and self._pool < optimum_threads:
 				log.debug("Creating %d threads." % (optimum_threads - self._pool))
 				for i in xrange(int(optimum_threads - self._pool)):
-					thread = Thread(target=self.wrapper)
-					thread.start()
-					self._pool += 1
+					self.spawn()
 					
 			self._finished.wait(self._interval)
 			
@@ -154,7 +157,8 @@ class MailPool(Pool):
 		
 		while True:
 			if not count < self._jobs:
-				log.debug("Worker death from old age.")
+				log.debug("Worker death from old age - spawning child.")
+				self.spawn()
 				break
 			
 			try:
